@@ -37,8 +37,12 @@
 (eval-and-compile
   (require 'ef-themes)
 
+;;;###theme-autoload
   (deftheme ef-bio
-    "Legible dark theme with green, teal, blue, purple colors.")
+    "Legible dark theme with green, teal, blue, purple colors."
+    :background-mode 'dark
+    :kind 'color-scheme
+    :family 'ef)
 
   (defconst ef-bio-palette
     '(
@@ -137,7 +141,6 @@
       (bg-hover           "#4f3f9a")
       (bg-hover-secondary "#003e5f")
       (bg-hl-line         "#00331f")
-      (bg-region          "#3a3027")
       (bg-paren           "#664950")
       (bg-err             "#381400") ; check with err
       (bg-warning         "#332800") ; check with warning
@@ -155,9 +158,9 @@
       (underline-warning "#c0b000")
       (underline-info    "#22b022")
 
-;;; Conditional hues
-
-      (bg-region-intense "#0f5450")
+      (bg-char-0 "#0050af")
+      (bg-char-1 "#7f1f7f")
+      (bg-char-2 "#625a00")
 
 ;;; Mappings
 
@@ -168,11 +171,14 @@
       (info green)
 
       (link green-cooler)
-      (link-alt cyan-cooler)
+      (link-alt magenta)
       (name green)
       (keybind green)
       (identifier magenta-faint)
-      (prompt green-warmer)
+      (prompt cyan-cooler)
+
+      (bg-region "#3a3027")
+      (fg-region unspecified)
 
 ;;;; Code mappings
 
@@ -216,6 +222,7 @@
       (prose-metadata fg-dim)
       (prose-metadata-value fg-alt)
       (prose-table fg-alt)
+      (prose-table-formula err)
       (prose-tag yellow-faint)
       (prose-todo red)
       (prose-verbatim green-cooler)
@@ -283,7 +290,4 @@ further details)."
 
   (provide-theme 'ef-bio))
 
-;;;###theme-autoload
-(put 'ef-bio 'theme-properties '(:background-mode dark :kind color-scheme :family ef))
-
 ;;; ef-bio-theme.el ends here
