@@ -37,8 +37,12 @@
 (eval-and-compile
   (require 'ef-themes)
 
+;;;###theme-autoload
   (deftheme ef-cherie
-    "Legible dark theme with warm colors (mostly pink, magenta, gold)")
+    "Legible dark theme with warm colors (mostly pink, magenta, gold)"
+    :background-mode 'dark
+    :kind 'color-scheme
+    :family 'ef)
 
   (defconst ef-cherie-palette
     '(
@@ -137,7 +141,6 @@
       (bg-hover           "#303f6f")
       (bg-hover-secondary "#66364f")
       (bg-hl-line         "#401f33")
-      (bg-region          "#232f3f")
       (bg-paren           "#3f5f75")
       (bg-err             "#3c0f12") ; check with err
       (bg-warning         "#352905") ; check with warning
@@ -155,9 +158,9 @@
       (underline-warning "#c0b000")
       (underline-info    "#22b022")
 
-;;; Conditional hues
-
-      (bg-region-intense "#3f3460")
+      (bg-char-0 "#0050af")
+      (bg-char-1 "#7f1f7f")
+      (bg-char-2 "#625a00")
 
 ;;; Mappings
 
@@ -174,6 +177,9 @@
       (identifier magenta-faint)
       (prompt magenta-warmer)
 
+      (bg-region "#232f3f")
+      (fg-region unspecified)
+
 ;;;; Code mappings
 
       (builtin blue-warmer)
@@ -216,6 +222,7 @@
       (prose-metadata fg-dim)
       (prose-metadata-value fg-alt)
       (prose-table fg-alt)
+      (prose-table-formula info)
       (prose-tag yellow-faint)
       (prose-todo red-warmer)
       (prose-verbatim magenta-warmer)
@@ -283,7 +290,4 @@ further details)."
 
   (provide-theme 'ef-cherie))
 
-;;;###theme-autoload
-(put 'ef-cherie 'theme-properties '(:background-mode dark :kind color-scheme :family ef))
-
 ;;; ef-cherie-theme.el ends here
