@@ -37,8 +37,12 @@
 (eval-and-compile
   (require 'ef-themes)
 
+;;;###theme-autoload
   (deftheme ef-cyprus
-    "Legible light theme with green, yellow, teal, red colors.")
+    "Legible light theme with green, yellow, teal, red colors."
+    :background-mode 'light
+    :kind 'color-scheme
+    :family 'ef)
 
   (defconst ef-cyprus-palette
     '(
@@ -137,7 +141,6 @@
       (bg-hover           "#efc26f")
       (bg-hover-secondary "#afc0f0")
       (bg-hl-line         "#f0e0d4")
-      (bg-region          "#e0e7e5")
       (bg-paren           "#9fcfdf")
       (bg-err             "#ffd4bf") ; check with err
       (bg-warning         "#f0e8ba") ; check with warning
@@ -155,9 +158,9 @@
       (underline-warning "#bf5f00")
       (underline-info    "#02af5f")
 
-;;; Conditional hues
-
-      (bg-region-intense "#dcd09f")
+      (bg-char-0 "#7feaff")
+      (bg-char-1 "#ffaaff")
+      (bg-char-2 "#dff000")
 
 ;;; Mappings
 
@@ -174,6 +177,9 @@
       (identifier green-faint)
       (prompt green)
 
+      (bg-region "#e0e7e5")
+      (fg-region unspecified)
+
 ;;;; Code mappings
 
       (builtin green-warmer)
@@ -216,6 +222,7 @@
       (prose-metadata fg-dim)
       (prose-metadata-value fg-alt)
       (prose-table fg-alt)
+      (prose-table-formula info)
       (prose-tag yellow-faint)
       (prose-todo red-warmer)
       (prose-verbatim green)
@@ -283,7 +290,4 @@ further details)."
 
   (provide-theme 'ef-cyprus))
 
-;;;###theme-autoload
-(put 'ef-cyprus 'theme-properties '(:background-mode light :kind color-scheme :family ef))
-
 ;;; ef-cyprus-theme.el ends here
