@@ -37,8 +37,12 @@
 (eval-and-compile
   (require 'ef-themes)
 
+;;;###theme-autoload
   (deftheme ef-dark
-    "Legible dark theme with blue, magenta, cyan, purple colors.")
+    "Legible dark theme with blue, magenta, cyan, purple colors."
+    :background-mode 'dark
+    :kind 'color-scheme
+    :family 'ef)
 
   (defconst ef-dark-palette
     '(
@@ -137,7 +141,6 @@
       (bg-hover           "#004a5f")
       (bg-hover-secondary "#551f5a")
       (bg-hl-line         "#002435")
-      (bg-region          "#2a234a")
       (bg-paren           "#20577a")
       (bg-err             "#360d09") ; check with err
       (bg-warning         "#332600") ; check with warning
@@ -155,9 +158,9 @@
       (underline-warning "#c0b000")
       (underline-info    "#22b022")
 
-;;; Conditional hues
-
-      (bg-region-intense "#3a3465")
+      (bg-char-0 "#0050af")
+      (bg-char-1 "#7f1f7f")
+      (bg-char-2 "#625a00")
 
 ;;; Mappings
 
@@ -174,6 +177,9 @@
       (identifier magenta-faint)
       (prompt green-cooler)
 
+      (bg-region "#2a234a")
+      (fg-region unspecified)
+
 ;;;; Code mappings
 
       (builtin magenta)
@@ -216,6 +222,7 @@
       (prose-metadata fg-dim)
       (prose-metadata-value fg-alt)
       (prose-table fg-alt)
+      (prose-table-formula err)
       (prose-tag yellow-faint)
       (prose-todo red-warmer)
       (prose-verbatim blue)
@@ -283,7 +290,4 @@ further details)."
 
   (provide-theme 'ef-dark))
 
-;;;###theme-autoload
-(put 'ef-dark 'theme-properties '(:background-mode dark :kind color-scheme :family ef))
-
 ;;; ef-dark-theme.el ends here
