@@ -37,8 +37,12 @@
 (eval-and-compile
   (require 'ef-themes)
 
+;;;###theme-autoload
   (deftheme ef-day
-    "Legible light theme with warm, varied colors (yellow, red, green, purple).")
+    "Legible light theme with warm, varied colors (yellow, red, green, purple)."
+    :background-mode 'light
+    :kind 'color-scheme
+    :family 'ef)
 
   (defconst ef-day-palette
     '(
@@ -137,7 +141,6 @@
       (bg-hover           "#b0e0df")
       (bg-hover-secondary "#febccf")
       (bg-hl-line         "#f9e2b2")
-      (bg-region          "#f0d2df")
       (bg-paren           "#8fcfdf")
       (bg-err             "#ffdde5") ; check with err
       (bg-warning         "#ffe0aa") ; check with warning
@@ -155,9 +158,9 @@
       (underline-warning "#bf5f00")
       (underline-info    "#02af52")
 
-;;; Conditional hues
-
-      (bg-region-intense "#dfc39a")
+      (bg-char-0 "#7feaff")
+      (bg-char-1 "#f0a0f0")
+      (bg-char-2 "#d0e000")
 
 ;;; Mappings
 
@@ -174,6 +177,9 @@
       (identifier magenta-faint)
       (prompt yellow)
 
+      (bg-region "#f0d2df")
+      (fg-region unspecified)
+
 ;;;; Code mappings
 
       (builtin red-cooler)
@@ -216,6 +222,7 @@
       (prose-metadata fg-dim)
       (prose-metadata-value fg-alt)
       (prose-table fg-alt)
+      (prose-table-formula info)
       (prose-tag yellow-faint)
       (prose-todo red-warmer)
       (prose-verbatim red)
@@ -283,7 +290,4 @@ further details)."
 
   (provide-theme 'ef-day))
 
-;;;###theme-autoload
-(put 'ef-day 'theme-properties '(:background-mode light :kind color-scheme :family ef))
-
 ;;; ef-day-theme.el ends here
