@@ -40,8 +40,12 @@
   ;; Most of the colors here, like the red and green hues, are defined
   ;; simply to preserve compatibility with the rest of the project.  We
   ;; don't actually rely on them for anything critical.
+;;;###theme-autoload
   (deftheme ef-deuteranopia-dark
-    "Legible dark theme, optimized for red-green color deficiency.")
+    "Legible dark theme, optimized for red-green color deficiency."
+    :background-mode 'dark
+    :kind 'color-scheme
+    :family 'ef)
 
   (defconst ef-deuteranopia-dark-palette
     '(
@@ -140,7 +144,6 @@
       (bg-hover           "#4f4f00")
       (bg-hover-secondary "#00405f")
       (bg-hl-line         "#2e2e1b")
-      (bg-region          "#223848")
       (bg-paren           "#0f4f9a")
       (bg-err             "#342b00") ; check with err
       (bg-warning         "#32351f") ; check with warning
@@ -158,9 +161,9 @@
       (underline-warning "#bfaf50")
       (underline-info    "#22cff2")
 
-;;; Conditional hues
-
-      (bg-region-intense "#1f2f70")
+      (bg-char-0 "#0050af")
+      (bg-char-1 "#7f1f7f")
+      (bg-char-2 "#625a00")
 
 ;;; Mappings
 
@@ -175,7 +178,10 @@
       (name blue-warmer)
       (keybind yellow-warmer)
       (identifier cyan-faint)
-      (prompt yellow)
+      (prompt blue-cooler)
+
+      (bg-region "#223848")
+      (fg-region unspecified)
 
 ;;;; Code mappings
 
@@ -219,6 +225,7 @@
       (prose-metadata fg-dim)
       (prose-metadata-value fg-alt)
       (prose-table fg-alt)
+      (prose-table-formula err)
       (prose-tag fg-alt)
       (prose-todo yellow-warmer)
       (prose-verbatim blue-cooler)
@@ -286,7 +293,4 @@ further details)."
 
   (provide-theme 'ef-deuteranopia-dark))
 
-;;;###theme-autoload
-(put 'ef-deuteranopia-dark 'theme-properties '(:background-mode dark :kind color-scheme :family ef))
-
 ;;; ef-deuteranopia-dark-theme.el ends here
