@@ -40,8 +40,12 @@
   ;; Most of the colors here are defined simply to preserve
   ;; compatibility with the rest of the project.  We don't actually rely
   ;; on them for anything critical.
+;;;###theme-autoload
   (deftheme ef-duo-dark
-    "Legible dark theme with mostly blue and orange colors.")
+    "Legible dark theme with mostly blue and orange colors."
+    :background-mode 'dark
+    :kind 'color-scheme
+    :family 'ef)
 
   (defconst ef-duo-dark-palette
     '(
@@ -140,7 +144,6 @@
       (bg-hover           "#664f4a")
       (bg-hover-secondary "#264f4a")
       (bg-hl-line         "#301a4f")
-      (bg-region          "#042a50")
       (bg-paren           "#2f608e")
       (bg-err             "#360d09") ; check with err
       (bg-warning         "#332600") ; check with warning
@@ -158,9 +161,9 @@
       (underline-warning "#c0b000")
       (underline-info    "#22b022")
 
-;;; Conditional hues
-
-      (bg-region-intense "#1f2f70")
+      (bg-char-0 "#0050af")
+      (bg-char-1 "#7f1f7f")
+      (bg-char-2 "#625a00")
 
 ;;; Mappings
 
@@ -177,6 +180,9 @@
       (identifier red-faint)
       (prompt yellow)
 
+      (bg-region "#042a50")
+      (fg-region unspecified)
+
 ;;;; Code mappings
 
       (builtin cyan)
@@ -219,6 +225,7 @@
       (prose-metadata fg-dim)
       (prose-metadata-value fg-alt)
       (prose-table fg-alt)
+      (prose-table-formula info)
       (prose-tag yellow-faint)
       (prose-todo red)
       (prose-verbatim blue-warmer)
@@ -286,7 +293,4 @@ further details)."
 
   (provide-theme 'ef-duo-dark))
 
-;;;###theme-autoload
-(put 'ef-duo-dark 'theme-properties '(:background-mode dark :kind color-scheme :family ef))
-
 ;;; ef-duo-dark-theme.el ends here
