@@ -40,8 +40,12 @@
   ;; Most of the colors here are defined simply to preserve
   ;; compatibility with the rest of the project.  We don't actually rely
   ;; on them for anything critical.
+;;;###theme-autoload
   (deftheme ef-duo-light
-    "Legible light theme with mostly blue and yellow colors.")
+    "Legible light theme with mostly blue and yellow colors."
+    :background-mode 'light
+    :kind 'color-scheme
+    :family 'ef)
 
   (defconst ef-duo-light-palette
     '(
@@ -140,7 +144,6 @@
       (bg-hover           "#b4cfff")
       (bg-hover-secondary "#aaeccf")
       (bg-hl-line         "#f9e8c0")
-      (bg-region          "#caeafa")
       (bg-paren           "#afbfef")
       (bg-err             "#ffdfe6") ; check with err
       (bg-warning         "#ffe5ba") ; check with warning
@@ -158,9 +161,9 @@
       (underline-warning "#bf5f00")
       (underline-info    "#02af52")
 
-;;; Conditional hues
-
-      (bg-region-intense "#dfc2b0")
+      (bg-char-0 "#7feaff")
+      (bg-char-1 "#ffaaff")
+      (bg-char-2 "#dff000")
 
 ;;; Mappings
 
@@ -175,7 +178,10 @@
       (name blue)
       (keybind blue-cooler)
       (identifier red-faint)
-      (prompt blue)
+      (prompt blue-warmer)
+
+      (bg-region "#caeafa")
+      (fg-region unspecified)
 
 ;;;; Code mappings
 
@@ -219,6 +225,7 @@
       (prose-metadata fg-dim)
       (prose-metadata-value fg-alt)
       (prose-table fg-alt)
+      (prose-table-formula info)
       (prose-tag yellow-faint)
       (prose-todo red)
       (prose-verbatim blue-warmer)
@@ -286,7 +293,4 @@ further details)."
 
   (provide-theme 'ef-duo-light))
 
-;;;###theme-autoload
-(put 'ef-duo-light 'theme-properties '(:background-mode light :kind color-scheme :family ef))
-
 ;;; ef-duo-light-theme.el ends here
