@@ -37,8 +37,12 @@
 (eval-and-compile
   (require 'ef-themes)
 
+;;;###theme-autoload
   (deftheme ef-frost
-    "Legible light theme with blue, cyan, teal, purple colors.")
+    "Legible light theme with blue, cyan, teal, purple colors."
+    :background-mode 'light
+    :kind 'color-scheme
+    :family 'ef)
 
   (defconst ef-frost-palette
     '(
@@ -104,9 +108,9 @@
       (bg-added-refine   "#b3efdf")
       (fg-added          "#004840")
 
-      (bg-changed        "#ffdfb9")
-      (bg-changed-faint  "#ffefcb")
-      (bg-changed-refine "#ffcfa0")
+      (bg-changed        "#f4e8bd")
+      (bg-changed-faint  "#f9efcb")
+      (bg-changed-refine "#efd299")
       (fg-changed        "#553d00")
 
       (bg-removed        "#ffd6e0")
@@ -137,7 +141,6 @@
       (bg-hover           "#eab5ff")
       (bg-hover-secondary "#aae0bf")
       (bg-hl-line         "#dff6e4")
-      (bg-region          "#d4eaf3")
       (bg-paren           "#cab0ef")
       (bg-err             "#ffdfda") ; check with err
       (bg-warning         "#ffe9bf") ; check with warning
@@ -155,9 +158,9 @@
       (underline-warning "#bf5f00")
       (underline-info    "#02af52")
 
-;;; Conditional hues
-
-      (bg-region-intense "#aadfcc")
+      (bg-char-0 "#7feaff")
+      (bg-char-1 "#ffaaff")
+      (bg-char-2 "#dff000")
 
 ;;; Mappings
 
@@ -172,7 +175,10 @@
       (name cyan-warmer)
       (keybind blue-cooler)
       (identifier magenta-faint)
-      (prompt blue)
+      (prompt cyan)
+
+      (bg-region "#d4eaf3")
+      (fg-region unspecified)
 
 ;;;; Code mappings
 
@@ -216,6 +222,7 @@
       (prose-metadata fg-dim)
       (prose-metadata-value fg-alt)
       (prose-table fg-alt)
+      (prose-table-formula err)
       (prose-tag yellow-faint)
       (prose-todo red)
       (prose-verbatim blue-warmer)
@@ -283,7 +290,4 @@ further details)."
 
   (provide-theme 'ef-frost))
 
-;;;###theme-autoload
-(put 'ef-frost 'theme-properties '(:background-mode light :kind color-scheme :family ef))
-
 ;;; ef-frost-theme.el ends here
