@@ -37,8 +37,12 @@
 (eval-and-compile
   (require 'ef-themes)
 
+;;;###theme-autoload
   (deftheme ef-kassio
-    "Legible light theme with blue, red, magenta, and earthly colors.")
+    "Legible light theme with blue, red, magenta, and earthly colors."
+    :background-mode 'light
+    :kind 'color-scheme
+    :family 'ef)
 
   (defconst ef-kassio-palette
     '(
@@ -137,7 +141,6 @@
       (bg-hover           "#c0d0ff")
       (bg-hover-secondary "#efd5ff")
       (bg-hl-line         "#f2e5d9")
-      (bg-region          "#dfe4f4")
       (bg-paren           "#b0dffa")
       (bg-err             "#ffdde5") ; check with err
       (bg-warning         "#ffe0aa") ; check with warning
@@ -155,9 +158,9 @@
       (underline-warning "#bf5f00")
       (underline-info    "#02af52")
 
-;;; Conditional hues
-
-      (bg-region-intense "#f0c0f0")
+      (bg-char-0 "#7feaff")
+      (bg-char-1 "#ffaaff")
+      (bg-char-2 "#dff000")
 
 ;;; Mappings
 
@@ -174,6 +177,9 @@
       (identifier yellow-cooler)
       (prompt blue-warmer)
 
+      (bg-region "#dfe4f4")
+      (fg-region unspecified)
+
 ;;;; Code mappings
 
       (builtin magenta)
@@ -216,6 +222,7 @@
       (prose-metadata fg-dim)
       (prose-metadata-value fg-alt)
       (prose-table yellow-faint)
+      (prose-table-formula info)
       (prose-tag magenta-faint)
       (prose-todo red-warmer)
       (prose-verbatim blue-warmer)
@@ -283,7 +290,4 @@ further details)."
 
   (provide-theme 'ef-kassio))
 
-;;;###theme-autoload
-(put 'ef-kassio 'theme-properties '(:background-mode light :kind color-scheme :family ef))
-
 ;;; ef-kassio-theme.el ends here
