@@ -37,8 +37,12 @@
 (eval-and-compile
   (require 'ef-themes)
 
+;;;###theme-autoload
   (deftheme ef-light
-    "Legible light theme with blue, magenta, cyan, purple colors.")
+    "Legible light theme with blue, magenta, cyan, purple colors."
+    :background-mode 'light
+    :kind 'color-scheme
+    :family 'ef)
 
   (defconst ef-light-palette
     '(
@@ -104,9 +108,9 @@
       (bg-added-refine   "#c6e8c6")
       (fg-added          "#005000")
 
-      (bg-changed        "#ffdfa9")
-      (bg-changed-faint  "#ffefbf")
-      (bg-changed-refine "#fac090")
+      (bg-changed        "#f4e8bd")
+      (bg-changed-faint  "#f9efcb")
+      (bg-changed-refine "#efd299")
       (fg-changed        "#553d00")
 
       (bg-removed        "#ffd8d5")
@@ -137,7 +141,6 @@
       (bg-hover           "#aaeccf")
       (bg-hover-secondary "#ccbfff")
       (bg-hl-line         "#e4efd8")
-      (bg-region          "#bfefff")
       (bg-paren           "#dfa0f3")
       (bg-err             "#ffd5ea") ; check with err
       (bg-warning         "#ffeabb") ; check with warning
@@ -155,9 +158,9 @@
       (underline-warning "#bf5f00")
       (underline-info    "#02af52")
 
-;;; Conditional hues
-
-      (bg-region-intense "#afdfc0")
+      (bg-char-0 "#7feaff")
+      (bg-char-1 "#ffaaff")
+      (bg-char-2 "#dff000")
 
 ;;; Mappings
 
@@ -174,6 +177,9 @@
       (identifier magenta-faint)
       (prompt green-cooler)
 
+      (bg-region "#bfefff")
+      (fg-region unspecified)
+
 ;;;; Code mappings
 
       (builtin magenta)
@@ -216,6 +222,7 @@
       (prose-metadata fg-dim)
       (prose-metadata-value fg-alt)
       (prose-table fg-alt)
+      (prose-table-formula err)
       (prose-tag green-faint)
       (prose-todo red-warmer)
       (prose-verbatim blue-warmer)
@@ -283,7 +290,4 @@ further details)."
 
   (provide-theme 'ef-light))
 
-;;;###theme-autoload
-(put 'ef-light 'theme-properties '(:background-mode light :kind color-scheme :family ef))
-
 ;;; ef-light-theme.el ends here
