@@ -37,8 +37,12 @@
 (eval-and-compile
   (require 'ef-themes)
 
+;;;###theme-autoload
   (deftheme ef-night
-    "Legible dark theme with mostly green, blue, purple colors.")
+    "Legible dark theme with mostly green, blue, purple colors."
+    :background-mode 'dark
+    :kind 'color-scheme
+    :family 'ef)
 
   (defconst ef-night-palette
     '(
@@ -137,7 +141,6 @@
       (bg-hover           "#6f345a")
       (bg-hover-secondary "#493737")
       (bg-hl-line         "#002255")
-      (bg-region          "#222f40")
       (bg-paren           "#664950")
       (bg-err             "#331419") ; check with err
       (bg-warning         "#332613") ; check with warning
@@ -155,9 +158,9 @@
       (underline-warning "#c0b000")
       (underline-info    "#22b022")
 
-;;; Conditional hues
-
-      (bg-region-intense "#3f2f60")
+      (bg-char-0 "#0050af")
+      (bg-char-1 "#7f1f7f")
+      (bg-char-2 "#625a00")
 
 ;;; Mappings
 
@@ -172,7 +175,10 @@
       (name blue-warmer)
       (keybind green-cooler)
       (identifier magenta-faint)
-      (prompt cyan-cooler)
+      (prompt cyan-warmer)
+
+      (bg-region "#222f40")
+      (fg-region unspecified)
 
 ;;;; Code mappings
 
@@ -216,6 +222,7 @@
       (prose-metadata fg-dim)
       (prose-metadata-value fg-alt)
       (prose-table fg-alt)
+      (prose-table-formula info)
       (prose-tag fg-alt)
       (prose-todo red)
       (prose-verbatim blue-cooler)
@@ -283,7 +290,4 @@ further details)."
 
   (provide-theme 'ef-night))
 
-;;;###theme-autoload
-(put 'ef-night 'theme-properties '(:background-mode dark :kind color-scheme :family ef))
-
 ;;; ef-night-theme.el ends here
