@@ -37,8 +37,12 @@
 (eval-and-compile
   (require 'ef-themes)
 
+;;;###theme-autoload
   (deftheme ef-spring
-    "Legible light theme with cool, varied colors (green, cyan, red).")
+    "Legible light theme with cool, varied colors (green, cyan, red)."
+    :background-mode 'light
+    :kind 'color-scheme
+    :family 'ef)
 
   (defconst ef-spring-palette
     '(
@@ -104,9 +108,9 @@
       (bg-added-refine   "#b3efcf")
       (fg-added          "#005000")
 
-      (bg-changed        "#ffdfb9")
-      (bg-changed-faint  "#ffefcb")
-      (bg-changed-refine "#ffcfa0")
+      (bg-changed        "#f0e8bd")
+      (bg-changed-faint  "#f5efcb")
+      (bg-changed-refine "#efd299")
       (fg-changed        "#553d00")
 
       (bg-removed        "#ffd6e0")
@@ -137,7 +141,6 @@
       (bg-hover           "#ffc09f")
       (bg-hover-secondary "#f0bfff")
       (bg-hl-line         "#f9e0e5")
-      (bg-region          "#d0e6ff")
       (bg-paren           "#7fddd0")
       (bg-err             "#ffe8e0") ; check with err
       (bg-warning         "#ffecba") ; check with warning
@@ -155,9 +158,9 @@
       (underline-warning "#bf5f00")
       (underline-info    "#02af52")
 
-;;; Conditional hues
-
-      (bg-region-intense "#cfb5f0")
+      (bg-char-0 "#7feaff")
+      (bg-char-1 "#ffaaff")
+      (bg-char-2 "#dff000")
 
 ;;; Mappings
 
@@ -174,6 +177,9 @@
       (identifier magenta-faint)
       (prompt green)
 
+      (bg-region "#d0e6ff")
+      (fg-region unspecified)
+
 ;;;; Code mappings
 
       (builtin green)
@@ -216,6 +222,7 @@
       (prose-metadata fg-dim)
       (prose-metadata-value fg-alt)
       (prose-table fg-alt)
+      (prose-table-formula info)
       (prose-tag magenta-faint)
       (prose-todo red-warmer)
       (prose-verbatim green)
@@ -283,7 +290,4 @@ further details)."
 
   (provide-theme 'ef-spring))
 
-;;;###theme-autoload
-(put 'ef-spring 'theme-properties '(:background-mode light :kind color-scheme :family ef))
-
 ;;; ef-spring-theme.el ends here
