@@ -37,8 +37,12 @@
 (eval-and-compile
   (require 'ef-themes)
 
+;;;###theme-autoload
   (deftheme ef-summer
-    "Legible light theme with magenta, purple, gold, cyan colors.")
+    "Legible light theme with magenta, purple, gold, cyan colors."
+    :background-mode 'light
+    :kind 'color-scheme
+    :family 'ef)
 
   (defconst ef-summer-palette
     '(
@@ -137,7 +141,6 @@
       (bg-hover           "#b4cfff")
       (bg-hover-secondary "#aaeccf")
       (bg-hl-line         "#ffd6e5")
-      (bg-region          "#eecfff")
       (bg-paren           "#9fc0ef")
       (bg-err             "#ffd0e6") ; check with err
       (bg-warning         "#ffe5ba") ; check with warning
@@ -155,9 +158,9 @@
       (underline-warning "#bf5f00")
       (underline-info    "#02af52")
 
-;;; Conditional hues
-
-      (bg-region-intense "#caaadf")
+      (bg-char-0 "#7feaff")
+      (bg-char-1 "#ffaaff")
+      (bg-char-2 "#dff000")
 
 ;;; Mappings
 
@@ -174,6 +177,9 @@
       (identifier magenta-faint)
       (prompt magenta-warmer)
 
+      (bg-region "#eecfff")
+      (fg-region unspecified)
+
 ;;;; Code mappings
 
       (builtin magenta)
@@ -216,6 +222,7 @@
       (prose-metadata fg-dim)
       (prose-metadata-value fg-alt)
       (prose-table fg-alt)
+      (prose-table-formula info)
       (prose-tag yellow-faint)
       (prose-todo red-warmer)
       (prose-verbatim magenta-cooler)
@@ -283,7 +290,4 @@ further details)."
 
   (provide-theme 'ef-summer))
 
-;;;###theme-autoload
-(put 'ef-summer 'theme-properties '(:background-mode light :kind color-scheme :family ef))
-
 ;;; ef-summer-theme.el ends here
