@@ -37,8 +37,12 @@
 (eval-and-compile
   (require 'ef-themes)
 
+;;;###theme-autoload
   (deftheme ef-symbiosis
-    "Legible dark theme with blue, magenta, cyan, purple colors.")
+    "Legible dark theme with blue, magenta, cyan, purple colors."
+    :background-mode 'dark
+    :kind 'color-scheme
+    :family 'ef)
 
   (defconst ef-symbiosis-palette
     '(
@@ -137,7 +141,6 @@
       (bg-hover           "#304477")
       (bg-hover-secondary "#5f3f3a")
       (bg-hl-line         "#1f2f3f")
-      (bg-region          "#2f2630")
       (bg-paren           "#005f4a")
       (bg-err             "#360d09") ; check with err
       (bg-warning         "#332600") ; check with warning
@@ -155,9 +158,9 @@
       (underline-warning "#c0b000")
       (underline-info    "#22b022")
 
-;;; Conditional hues
-
-      (bg-region-intense "#425425")
+      (bg-char-0 "#0050af")
+      (bg-char-1 "#7f1f7f")
+      (bg-char-2 "#625a00")
 
 ;;; Mappings
 
@@ -174,6 +177,9 @@
       (identifier yellow-faint)
       (prompt cyan)
 
+      (bg-region "#2f2630")
+      (fg-region unspecified)
+
 ;;;; Code mappings
 
       (builtin blue)
@@ -216,6 +222,7 @@
       (prose-metadata fg-dim)
       (prose-metadata-value fg-alt)
       (prose-table fg-alt)
+      (prose-table-formula err)
       (prose-tag magenta-faint)
       (prose-todo red)
       (prose-verbatim blue-warmer)
@@ -283,7 +290,4 @@ further details)."
 
   (provide-theme 'ef-symbiosis))
 
-;;;###theme-autoload
-(put 'ef-symbiosis 'theme-properties '(:background-mode dark :kind color-scheme :family ef))
-
 ;;; ef-symbiosis-theme.el ends here
