@@ -37,8 +37,12 @@
 (eval-and-compile
   (require 'ef-themes)
 
+;;;###theme-autoload
   (deftheme ef-trio-dark
-    "Legible dark theme with magenta, blue, teal colors.")
+    "Legible dark theme with magenta, blue, teal colors."
+    :background-mode 'dark
+    :kind 'color-scheme
+    :family 'ef)
 
   (defconst ef-trio-dark-palette
     '(
@@ -137,7 +141,6 @@
       (bg-hover           "#004f3f")
       (bg-hover-secondary "#452f5f")
       (bg-hl-line         "#34223f")
-      (bg-region          "#16304f")
       (bg-paren           "#2f605e")
       (bg-err             "#3a0f06") ; check with err
       (bg-warning         "#332910") ; check with warning
@@ -155,9 +158,9 @@
       (underline-warning "#c0b000")
       (underline-info    "#22b022")
 
-;;; Conditional hues
-
-      (bg-region-intense "#5d336c")
+      (bg-char-0 "#0050af")
+      (bg-char-1 "#7f1f7f")
+      (bg-char-2 "#625a00")
 
 ;;; Mappings
 
@@ -168,12 +171,15 @@
       (info green)
 
       (link cyan)
-      (link-alt magenta)
+      (link-alt green-warmer)
       (name blue)
       (keybind magenta-warmer)
       (identifier red-faint)
       (prompt blue-cooler)
 
+      (bg-region "#16304f")
+      (fg-region unspecified)
+
 ;;;; Code mappings
 
       (builtin magenta-cooler)
@@ -216,6 +222,7 @@
       (prose-metadata fg-dim)
       (prose-metadata-value fg-alt)
       (prose-table fg-alt)
+      (prose-table-formula err)
       (prose-tag magenta-faint)
       (prose-todo red-warmer)
       (prose-verbatim magenta-warmer)
@@ -283,7 +290,4 @@ further details)."
 
   (provide-theme 'ef-trio-dark))
 
-;;;###theme-autoload
-(put 'ef-trio-dark 'theme-properties '(:background-mode dark :kind color-scheme :family ef))
-
 ;;; ef-trio-dark-theme.el ends here
