@@ -37,8 +37,12 @@
 (eval-and-compile
   (require 'ef-themes)
 
+;;;###theme-autoload
   (deftheme ef-trio-light
-    "Legible light theme with magenta, blue, and teal colors.")
+    "Legible light theme with magenta, blue, and teal colors."
+    :background-mode 'light
+    :kind 'color-scheme
+    :family 'ef)
 
   (defconst ef-trio-light-palette
     '(
@@ -137,7 +141,6 @@
       (bg-hover           "#aaeccf")
       (bg-hover-secondary "#b4cfff")
       (bg-hl-line         "#cfe6ff")
-      (bg-region          "#eed0ff")
       (bg-paren           "#dfadaf")
       (bg-err             "#ffdfe6") ; check with err
       (bg-warning         "#ffe5bf") ; check with warning
@@ -155,9 +158,9 @@
       (underline-warning "#bf5f00")
       (underline-info    "#02af52")
 
-;;; Conditional hues
-
-      (bg-region-intense "#aacacf")
+      (bg-char-0 "#7feaff")
+      (bg-char-1 "#ffaaff")
+      (bg-char-2 "#dff000")
 
 ;;; Mappings
 
@@ -168,12 +171,15 @@
       (info green)
 
       (link cyan)
-      (link-alt magenta)
+      (link-alt green-warmer)
       (name blue)
       (keybind magenta-warmer)
       (identifier red-faint)
       (prompt blue-cooler)
 
+      (bg-region "#eed0ff")
+      (fg-region unspecified)
+
 ;;;; Code mappings
 
       (builtin magenta-cooler)
@@ -216,6 +222,7 @@
       (prose-metadata fg-dim)
       (prose-metadata-value fg-alt)
       (prose-table fg-alt)
+      (prose-table-formula err)
       (prose-tag magenta-faint)
       (prose-todo red-warmer)
       (prose-verbatim magenta-warmer)
@@ -283,7 +290,4 @@ further details)."
 
   (provide-theme 'ef-trio-light))
 
-;;;###theme-autoload
-(put 'ef-trio-light 'theme-properties '(:background-mode light :kind color-scheme :family ef))
-
 ;;; ef-trio-light-theme.el ends here
