@@ -40,8 +40,12 @@
   ;; Most of the colors here, like the blue and green hues, are defined
   ;; simply to preserve compatibility with the rest of the project.  We
   ;; don't actually rely on them for anything critical.
+;;;###theme-autoload
   (deftheme ef-tritanopia-dark
-    "Legible dark theme, optimized for blue-yellow color deficiency.")
+    "Legible dark theme, optimized for blue-yellow color deficiency."
+    :background-mode 'dark
+    :kind 'color-scheme
+    :family 'ef)
 
   (defconst ef-tritanopia-dark-palette
     '(
@@ -140,7 +144,6 @@
       (bg-hover           "#00405f")
       (bg-hover-secondary "#5e3e5b")
       (bg-hl-line         "#3f1515")
-      (bg-region          "#202d3f")
       (bg-paren           "#2f5f7a")
       (bg-err             "#3a0f0f") ; check with err
       (bg-warning         "#371430") ; check with warning
@@ -158,9 +161,9 @@
       (underline-warning "#ffafa0")
       (underline-info    "#22ffd2")
 
-;;; Conditional hues
-
-      (bg-region-intense "#5f303f")
+      (bg-char-0 "#922a00")
+      (bg-char-1 "#00709f")
+      (bg-char-2 "#5f3faf")
 
 ;;; Mappings
 
@@ -177,6 +180,9 @@
       (identifier magenta-faint)
       (prompt cyan)
 
+      (bg-region "#202d3f")
+      (fg-region unspecified)
+
 ;;;; Code mappings
 
       (builtin magenta)
@@ -219,6 +225,7 @@
       (prose-metadata fg-dim)
       (prose-metadata-value fg-alt)
       (prose-table fg-alt)
+      (prose-table-formula err)
       (prose-tag fg-alt)
       (prose-todo red-warmer)
       (prose-verbatim cyan)
@@ -286,7 +293,4 @@ further details)."
 
   (provide-theme 'ef-tritanopia-dark))
 
-;;;###theme-autoload
-(put 'ef-tritanopia-dark 'theme-properties '(:background-mode dark :kind color-scheme :family ef))
-
 ;;; ef-tritanopia-dark-theme.el ends here
