@@ -40,8 +40,12 @@
   ;; Most of the colors here, like the blue and green hues, are defined
   ;; simply to preserve compatibility with the rest of the project.  We
   ;; don't actually rely on them for anything critical.
+;;;###theme-autoload
   (deftheme ef-tritanopia-light
-    "Legible light theme, optimized for blue-yellow color deficiency.")
+    "Legible light theme, optimized for blue-yellow color deficiency."
+    :background-mode 'light
+    :kind 'color-scheme
+    :family 'ef)
 
   (defconst ef-tritanopia-light-palette
     '(
@@ -140,7 +144,6 @@
       (bg-hover           "#8fcfff")
       (bg-hover-secondary "#eda9dc")
       (bg-hl-line         "#ffdadf")
-      (bg-region          "#dadadf")
       (bg-paren           "#8fc0cf")
       (bg-err             "#ffbfca") ; check with err
       (bg-warning         "#efcae6") ; check with warning
@@ -158,9 +161,9 @@
       (underline-warning "#af7f90")
       (underline-info    "#22afc2")
 
-;;; Conditional hues
-
-      (bg-region-intense "#dfa5a5")
+      (bg-char-0 "#ff908f")
+      (bg-char-1 "#bfbfff")
+      (bg-char-2 "#5fcfdf")
 
 ;;; Mappings
 
@@ -177,6 +180,9 @@
       (identifier magenta-faint)
       (prompt cyan)
 
+      (bg-region "#dadadf")
+      (fg-region unspecified)
+
 ;;;; Code mappings
 
       (builtin magenta)
@@ -219,6 +225,7 @@
       (prose-metadata fg-dim)
       (prose-metadata-value fg-alt)
       (prose-table fg-alt)
+      (prose-table-formula err)
       (prose-tag fg-alt)
       (prose-todo red-warmer)
       (prose-verbatim cyan)
@@ -286,7 +293,4 @@ further details)."
 
   (provide-theme 'ef-tritanopia-light))
 
-;;;###theme-autoload
-(put 'ef-tritanopia-light 'theme-properties '(:background-mode light :kind color-scheme :family ef))
-
 ;;; ef-tritanopia-light-theme.el ends here
